pacman-game
===============================

version number: 1.0.3.dev1
author: Parth Kolekar

Overview
--------

A Pacman Like Game with new and interesting new features.

Installation / Usage
--------------------

To install use pip:

    $ pip install pacman-game


Or clone the repo:

    $ git clone https://github.com/ParthKolekar/pacman-game.git
    $ python setup.py install
    
